Dcubo Iconify Template

style: very good analysis Powered by Mason License: MIT

Template of an icon set

Installation ๐Ÿ’ป

โ— In order to start using Dcubo Iconify Template you must have the Dart SDK installed on your machine.

Install via dart pub add:

dart pub add dcubo_iconify_template

Continuous Integration ๐Ÿค–

Dcubo Iconify Template comes with a built-in GitHub Actions workflow powered by Very Good Workflows but you can also add your preferred CI/CD solution.

Out of the box, on each pull request and push, the CI formats, lints, and tests the code. This ensures the code remains consistent and behaves correctly as you add functionality or make changes. The project uses Very Good Analysis for a strict set of analysis options used by our team. Code coverage is enforced using the Very Good Workflows.


Running Tests ๐Ÿงช

To run all unit tests:

dart pub global activate coverage 1.2.0
dart test --coverage=coverage
dart pub global run coverage:format_coverage --lcov --in=coverage --out=coverage/lcov.info

To view the generated coverage report you can use lcov.

# Generate Coverage Report
genhtml coverage/lcov.info -o coverage/

# Open Coverage Report
open coverage/index.html

Libraries

dcubo_iconify_ant_design
Iconify icons for ant-design.